Index: auxdir/tclmico.cc
--- auxdir/tclmico.cc.orig	2003-10-13 11:49:22.000000000 +0200
+++ auxdir/tclmico.cc	2003-10-13 20:02:21.000000000 +0200
@@ -48,9 +48,9 @@
     TclDispatcher *disp = event->disp;
     CORBA::Long handle = event->handle;
 
-    set<FileEvent *, less<FileEvent *> > seen;
+    std::set<FileEvent *, std::less<FileEvent *> > seen;
     while (42) {
-	list<FileEvent *>::iterator i;
+	std::list<FileEvent *>::iterator i;
 	for (i = disp->fevents.begin(); i != disp->fevents.end(); ++i) {
 	    if ((*i)->handle != handle)
 		continue;
@@ -82,7 +82,7 @@
     TimerEvent *event = (TimerEvent *)_event;
     TclDispatcher *disp = event->disp;
 
-    list<TimerEvent *>::iterator i;
+    std::list<TimerEvent *>::iterator i;
     for (i = disp->tevents.begin(); i != disp->tevents.end(); ++i) {
         if ((*i) == event) {
 	  disp->tevents.erase(i);
@@ -99,13 +99,13 @@
 
 TclDispatcher::~TclDispatcher ()
 {
-    list<FileEvent *>::iterator i;
+    std::list<FileEvent *>::iterator i;
     for (i = fevents.begin(); i != fevents.end(); ++i) {
 	(*i)->cb->callback (this, Remove);
 	delete *i;
     }
 
-    list<TimerEvent *>::iterator j;
+    std::list<TimerEvent *>::iterator j;
     for (j = tevents.begin(); j != tevents.end(); ++j) {
 	(*j)->cb->callback (this, Remove);
 	delete *j;
@@ -125,7 +125,7 @@
     ev = 0;
     int mask = 0;
 
-    list<FileEvent *>::iterator i;
+    std::list<FileEvent *>::iterator i;
     for (i = fevents.begin(); i != fevents.end(); ++i) {
 	if ((*i)->handle != handle)
 	    continue;
@@ -185,7 +185,7 @@
 TclDispatcher::remove (CORBA::DispatcherCallback *cb, Event e)
 {
     if (e == All || e == Timer) {
-	list<TimerEvent *>::iterator i, next;
+	std::list<TimerEvent *>::iterator i, next;
 	for (i = tevents.begin(); i != tevents.end(); i = next) {
 	    next = i;
 	    ++next;
@@ -197,7 +197,7 @@
 	}
     }
     if (e == All || e == Read || e == Write || e == Except) {
-	list<FileEvent *>::iterator i, next;
+	std::list<FileEvent *>::iterator i, next;
 	for (i = fevents.begin(); i != fevents.end(); i = next) {
 	    next = i;
 	    ++next;
Index: include/mico/os-math.h
--- include/mico/os-math.h.orig	2003-10-13 11:49:32.000000000 +0200
+++ include/mico/os-math.h	2003-10-13 20:02:21.000000000 +0200
@@ -296,11 +296,7 @@
 #include <unistd.h>
 #include <signal.h>
 #include <sys/types.h>
-
-#if !defined(__GNUG__) || !defined(__sgi)
-// conflict for initstate ()
-#include <math.h>
-#endif
+#include <cmath>
 
 #ifdef HAVE_FLOAT_H
 #include <float.h>
@@ -360,6 +356,7 @@
 
     static MICO_Boolean is_infinity (MICO_Double d)
     {
+        using namespace std;
 #if defined(HAVE_ISINF)
 	return isinf (d);
 #elif defined(HAVE_FINITE) && defined(HAVE_ISNAN)
@@ -371,6 +368,7 @@
 
     static MICO_Boolean is_nan (MICO_Double d)
     {
+        using namespace std;
 #if defined(HAVE_ISNAN)
 	return isnan (d);
 #else
@@ -419,6 +417,7 @@
 
     static MICO_Boolean is_infinityl (MICO_LongDouble d)
     {
+        using namespace std;
 #if defined(HAVE_ISINFL)
 	return isinfl (d);
 #elif defined(HAVE_ISINF)
@@ -430,6 +429,7 @@
 
     static MICO_Boolean is_nanl (MICO_LongDouble d)
     {
+        using namespace std;
 #if defined(HAVE_ISNANL)
 	return isnanl (d);
 #elif defined(HAVE_ISNAN)
Index: Makefile
--- Makefile.orig	2003-10-13 11:49:22.000000000 +0200
+++ Makefile	2003-10-13 20:02:21.000000000 +0200
@@ -73,7 +73,7 @@
 		$(IDIRCMD) $(SHARED_INSTDIR)/doc/mico; \
 		$(IMANCMD) doc/doc.ps $(SHARED_INSTDIR)/doc/mico/manual.ps; \
 	fi
-	-ldconfig
+#	-ldconfig
 
 install-cd:
 	for i in $(INSTALLDIRS); do $(MAKE) -C $$i install-cd || exit 1; done
Index: configure.in
--- configure.in.orig	2004-05-26 13:15:46.000000000 +0200
+++ configure.in	2004-05-26 13:16:36.000000000 +0200
@@ -1233,10 +1233,23 @@
 AC_FUNC_VPRINTF
 AC_LANG_CPLUSPLUS
 AC_CHECK_FUNCS(strdup strerror gethostname infnan isnan isinf finite)
-AC_CHECK_FUNCS(infnanl isnanl isinfl asinl ldexpl frexpl fabsl floorl ceill)
+AC_CHECK_FUNCS(infnanl isnanl isinfl ldexpl frexpl fabsl floorl ceill)
 AC_CHECK_FUNCS(powl fmodl dlopen shl_load ftime)
 AC_CHECK_FUNCS(backtrace backtrace_symbols)
 
+# Warning, the following is for documentation purposes only and does not
+# generate code compatible with that of the pristine MICO distribution.
+#
+#   - MSvB (26 May 2004)
+#
+# Check for asinl, but do more than search for a symbol in standard library
+AC_LANG_PUSH(C++)
+AC_MSG_CHECKING(for asinl)
+AC_COMPILE_IFELSE([AC_LANG_PROGRAM(#include <cmath>, asinl(2.0);)],
+                  [AC_DEFINE(HAVE_ASINL) AC_MSG_RESULT(yes)],
+                  [AC_MSG_RESULT(no)])
+AC_LANG_POP(C++)
+
 #
 # size of datatypes
 #
Index: configure
--- configure.orig	2003-10-13 11:49:22.000000000 +0200
+++ configure	2004-05-24 20:54:37.456564640 +0200
@@ -1424,7 +1424,7 @@
 
 cat > conftest.$ac_ext << EOF
 
-#line 1428 "configure"
+#line 1427 "configure"
 #include "confdefs.h"
 
 main(){return(0);}
@@ -1535,7 +1535,7 @@
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp.
   cat > conftest.$ac_ext <<EOF
-#line 1539 "configure"
+#line 1538 "configure"
 #include "confdefs.h"
 #include <assert.h>
 Syntax Error
@@ -1552,7 +1552,7 @@
   rm -rf conftest*
   CPP="${CC-cc} -E -traditional-cpp"
   cat > conftest.$ac_ext <<EOF
-#line 1556 "configure"
+#line 1555 "configure"
 #include "confdefs.h"
 #include <assert.h>
 Syntax Error
@@ -1569,7 +1569,7 @@
   rm -rf conftest*
   CPP="${CC-cc} -nologo -E"
   cat > conftest.$ac_ext <<EOF
-#line 1573 "configure"
+#line 1572 "configure"
 #include "confdefs.h"
 #include <assert.h>
 Syntax Error
@@ -1648,7 +1648,7 @@
 
 cat > conftest.$ac_ext << EOF
 
-#line 1652 "configure"
+#line 1651 "configure"
 #include "confdefs.h"
 
 int main(){return(0);}
@@ -1757,7 +1757,7 @@
 cross_compiling=$ac_cv_prog_cxx_cross
   CXXCPP="${CXX-g++} -E"
   cat > conftest.$ac_ext <<EOF
-#line 1761 "configure"
+#line 1760 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 EOF
@@ -1891,7 +1891,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lpthread  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 1895 "configure"
+#line 1894 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -1936,7 +1936,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1940 "configure"
+#line 1939 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -1978,7 +1978,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1982 "configure"
+#line 1981 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2026,7 +2026,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lc_r  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2030 "configure"
+#line 2029 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -2071,7 +2071,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2075 "configure"
+#line 2074 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2113,7 +2113,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2117 "configure"
+#line 2116 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2172,7 +2172,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lthread  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2176 "configure"
+#line 2175 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -2217,7 +2217,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2221 "configure"
+#line 2220 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2276,7 +2276,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lcma  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2280 "configure"
+#line 2279 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -2321,7 +2321,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2325 "configure"
+#line 2324 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2418,7 +2418,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2422 "configure"
+#line 2421 "configure"
 #include "confdefs.h"
 #include <$PTH_INCLUDE_DIR/pth.h>
 EOF
@@ -2453,7 +2453,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lpth "-L$PTH_LIB_DIR" $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2457 "configure"
+#line 2456 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -2517,7 +2517,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lpthread  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2521 "configure"
+#line 2520 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -2562,7 +2562,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2566 "configure"
+#line 2565 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2604,7 +2604,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2608 "configure"
+#line 2607 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2650,7 +2650,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lc_r  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2654 "configure"
+#line 2653 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -2695,7 +2695,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2699 "configure"
+#line 2698 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2737,7 +2737,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2741 "configure"
+#line 2740 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2783,7 +2783,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lthread  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2787 "configure"
+#line 2786 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -2828,7 +2828,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2832 "configure"
+#line 2831 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -2876,7 +2876,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lcma  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2880 "configure"
+#line 2879 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -2921,7 +2921,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2925 "configure"
+#line 2924 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -3006,7 +3006,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3010 "configure"
+#line 3009 "configure"
 #include "confdefs.h"
 #include <$PTH_INCLUDE_DIR/pth.h>
 EOF
@@ -3041,7 +3041,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lpth "-L$PTH_LIB_DIR" $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 3045 "configure"
+#line 3044 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -3514,7 +3514,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-liberty  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 3518 "configure"
+#line 3517 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -3564,7 +3564,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lbfd  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 3568 "configure"
+#line 3567 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -3614,7 +3614,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3618 "configure"
+#line 3617 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -3743,7 +3743,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-l$ac_lib  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 3747 "configure"
+#line 3746 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -4016,7 +4016,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lqt-mt  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 4020 "configure"
+#line 4019 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -4165,7 +4165,7 @@
   echo $ac_n "cross compiling; assumed OK... $ac_c"
 else
   cat > conftest.$ac_ext <<EOF
-#line 4169 "configure"
+#line 4168 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -4265,7 +4265,7 @@
           CXXFLAGS="$CXXFLAGS $GTK_CFLAGS"
           LIBS="$LIBS $GTK_LIBS"
           cat > conftest.$ac_ext <<EOF
-#line 4269 "configure"
+#line 4268 "configure"
 #include "confdefs.h"
 
 #include <gtk/gtk.h>
@@ -4364,7 +4364,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lm  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 4368 "configure"
+#line 4367 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -4416,7 +4416,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lnsl -lsocket $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 4420 "configure"
+#line 4419 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -4528,7 +4528,7 @@
 
   # First, try using that file with no special directory specified.
 cat > conftest.$ac_ext <<EOF
-#line 4532 "configure"
+#line 4531 "configure"
 #include "confdefs.h"
 #include <$x_direct_test_include>
 EOF
@@ -4602,7 +4602,7 @@
   ac_save_LIBS="$LIBS"
   LIBS="-l$x_direct_test_library $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 4606 "configure"
+#line 4605 "configure"
 #include "confdefs.h"
 
 int main() {
@@ -4718,7 +4718,7 @@
 echo "configure:4719: checking whether -R must be followed by a space" >&5
       ac_xsave_LIBS="$LIBS"; LIBS="$LIBS -R$x_libraries"
       cat > conftest.$ac_ext <<EOF
-#line 4722 "configure"
+#line 4721 "configure"
 #include "confdefs.h"
 
 int main() {
@@ -4741,7 +4741,7 @@
       else
 	LIBS="$ac_xsave_LIBS -R $x_libraries"
 	cat > conftest.$ac_ext <<EOF
-#line 4745 "configure"
+#line 4744 "configure"
 #include "confdefs.h"
 
 int main() {
@@ -4788,7 +4788,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-ldnet  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 4792 "configure"
+#line 4791 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -4832,7 +4832,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-ldnet_stub  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 4836 "configure"
+#line 4835 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -4880,7 +4880,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 4884 "configure"
+#line 4883 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char gethostbyname(); below.  */
@@ -4935,7 +4935,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lnsl  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 4939 "configure"
+#line 4938 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -4984,7 +4984,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 4988 "configure"
+#line 4987 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char connect(); below.  */
@@ -5039,7 +5039,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lsocket $X_EXTRA_LIBS $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5043 "configure"
+#line 5042 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5082,7 +5082,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 5086 "configure"
+#line 5085 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char remove(); below.  */
@@ -5137,7 +5137,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lposix  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5141 "configure"
+#line 5140 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5180,7 +5180,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 5184 "configure"
+#line 5183 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char shmat(); below.  */
@@ -5235,7 +5235,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lipc  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5239 "configure"
+#line 5238 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5290,7 +5290,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lICE $X_EXTRA_LIBS $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5294 "configure"
+#line 5293 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5342,7 +5342,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lsocket  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5346 "configure"
+#line 5345 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5392,7 +5392,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lbsd  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5396 "configure"
+#line 5395 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5443,7 +5443,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lelf  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5447 "configure"
+#line 5446 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5493,7 +5493,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-ldl  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5497 "configure"
+#line 5496 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5543,7 +5543,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-ldld  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5547 "configure"
+#line 5546 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5593,7 +5593,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lld  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5597 "configure"
+#line 5596 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5645,7 +5645,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lwsock32  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5649 "configure"
+#line 5648 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5704,7 +5704,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lcrypto  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5708 "configure"
+#line 5707 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5754,7 +5754,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lssl  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5758 "configure"
+#line 5757 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5829,7 +5829,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lpq  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5833 "configure"
+#line 5832 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5900,7 +5900,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lncurses  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5904 "configure"
+#line 5903 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -5952,7 +5952,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-ltermcap  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 5956 "configure"
+#line 5955 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -6003,7 +6003,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lHcurses  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 6007 "configure"
+#line 6006 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -6054,7 +6054,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lcurses  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 6058 "configure"
+#line 6057 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -6106,7 +6106,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lreadline  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 6110 "configure"
+#line 6109 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 #ifdef __cplusplus
@@ -6173,7 +6173,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6177 "configure"
+#line 6176 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 #include <stdarg.h>
@@ -6198,7 +6198,7 @@
 if test $ac_cv_header_stdc = yes; then
   # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
 cat > conftest.$ac_ext <<EOF
-#line 6202 "configure"
+#line 6201 "configure"
 #include "confdefs.h"
 #include <string.h>
 EOF
@@ -6216,7 +6216,7 @@
 if test $ac_cv_header_stdc = yes; then
   # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
 cat > conftest.$ac_ext <<EOF
-#line 6220 "configure"
+#line 6219 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 EOF
@@ -6237,7 +6237,7 @@
   :
 else
   cat > conftest.$ac_ext <<EOF
-#line 6241 "configure"
+#line 6240 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -6283,7 +6283,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6287 "configure"
+#line 6286 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -6323,7 +6323,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6327 "configure"
+#line 6326 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -6363,7 +6363,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6367 "configure"
+#line 6366 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -6404,7 +6404,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6408 "configure"
+#line 6407 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -6446,7 +6446,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6450 "configure"
+#line 6449 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -6488,7 +6488,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6492 "configure"
+#line 6491 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -6531,7 +6531,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6535 "configure"
+#line 6534 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
@@ -6583,7 +6583,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6587 "configure"
+#line 6586 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/time.h>
@@ -6618,7 +6618,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6622 "configure"
+#line 6621 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -6642,7 +6642,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 6646 "configure"
+#line 6645 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -6703,7 +6703,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 6707 "configure"
+#line 6706 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -6749,7 +6749,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 6753 "configure"
+#line 6752 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -6799,7 +6799,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 6803 "configure"
+#line 6802 "configure"
 #include "confdefs.h"
 
 #include <sys/time.h>
@@ -6839,7 +6839,7 @@
   LFSCANF=cross
 else
   cat > conftest.$ac_ext <<EOF
-#line 6843 "configure"
+#line 6842 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -6896,7 +6896,7 @@
   LFPRINTF=cross
 else
   cat > conftest.$ac_ext <<EOF
-#line 6900 "configure"
+#line 6899 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -6964,7 +6964,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 6968 "configure"
+#line 6967 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char vprintf(); below.  */
@@ -7016,7 +7016,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 7020 "configure"
+#line 7019 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char _doprnt(); below.  */
@@ -7078,7 +7078,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 7082 "configure"
+#line 7081 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -7128,7 +7128,7 @@
 fi
 done
 
-for ac_func in infnanl isnanl isinfl asinl ldexpl frexpl fabsl floorl ceill
+for ac_func in infnanl isnanl isinfl fabsl
 do
 echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
 echo "configure:7135: checking for $ac_func" >&5
@@ -7136,7 +7136,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 7140 "configure"
+#line 7139 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -7186,7 +7186,7 @@
 fi
 done
 
-for ac_func in powl fmodl dlopen shl_load ftime
+for ac_func in powl dlopen shl_load ftime
 do
 echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
 echo "configure:7193: checking for $ac_func" >&5
@@ -7194,7 +7194,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 7198 "configure"
+#line 7197 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -7252,7 +7252,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 7256 "configure"
+#line 7255 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -7304,6 +7304,359 @@
 
 
 #
+# Check for asinl, but do more than search for a symbol in standard library
+#
+ac_ext=cc
+ac_cpp='$CXXCPP $CPPFLAGS'
+ac_compile='$CXX -c $CXXFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CXX -o conftest$ac_exeext $CXXFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
+
+echo $ac_n "checking for asinl... $ac_c" 1>&6
+echo "configure:7316: checking for asinl" >&5
+cat >conftest.$ac_ext <<_ACEOF
+/* confdefs.h.  */
+_ACEOF
+cat confdefs.h >>conftest.$ac_ext
+cat >>conftest.$ac_ext <<_ACEOF
+/* end confdefs.h.  */
+#include <cmath>
+int
+main ()
+{
+asinl(2.0);
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext
+if { (eval echo "configure:7334: \"$ac_compile\"") >&5
+  (eval $ac_compile) 2>conftest.er1
+  ac_status=$?
+  grep -v '^ *+' conftest.er1 >conftest.err
+  rm -f conftest.er1
+  cat conftest.err >&5
+  echo "configure:7340: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+	 { ac_try='test -z "$ac_cxx_werror_flag"
+			 || test ! -s conftest.err'
+  { (eval echo "configure:7344: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7347: \$? = $ac_status" >&5
+  (exit $ac_status); }; } &&
+	 { ac_try='test -s conftest.$ac_objext'
+  { (eval echo "configure:7350: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7353: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  cat >>confdefs.h <<\_ACEOF
+#define HAVE_ASINL 1
+_ACEOF
+ echo "configure:7358: result: yes" >&5
+echo "$ac_t""yes" 1>&6
+else
+  echo "configure: failed program was:" >&5
+sed 's/^/| /' conftest.$ac_ext >&5
+
+echo "configure:7364: result: no" >&5
+echo "$ac_t""no" 1>&6
+fi
+rm -f conftest.err conftest.$ac_objext conftest.$ac_ext
+
+
+#
+# Check for ldexpl, but do more than search for a symbol in standard library
+#
+echo $ac_n "checking for ldexpl... $ac_c" 1>&6
+echo "configure:7316: checking for ldexpl" >&5
+cat >conftest.$ac_ext <<_ACEOF
+/* confdefs.h.  */
+_ACEOF
+cat confdefs.h >>conftest.$ac_ext
+cat >>conftest.$ac_ext <<_ACEOF
+/* end confdefs.h.  */
+#include <cmath>
+int
+main ()
+{
+ldexpl(1, 2);
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext
+if { (eval echo "configure:7334: \"$ac_compile\"") >&5
+  (eval $ac_compile) 2>conftest.er1
+  ac_status=$?
+  grep -v '^ *+' conftest.er1 >conftest.err
+  rm -f conftest.er1
+  cat conftest.err >&5
+  echo "configure:7340: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+	 { ac_try='test -z "$ac_cxx_werror_flag"
+			 || test ! -s conftest.err'
+  { (eval echo "configure:7344: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7347: \$? = $ac_status" >&5
+  (exit $ac_status); }; } &&
+	 { ac_try='test -s conftest.$ac_objext'
+  { (eval echo "configure:7350: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7353: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  cat >>confdefs.h <<\_ACEOF
+#define HAVE_LDEXPL 1
+_ACEOF
+ echo "configure:7358: result: yes" >&5
+echo "$ac_t""yes" 1>&6
+else
+  echo "configure: failed program was:" >&5
+sed 's/^/| /' conftest.$ac_ext >&5
+
+echo "configure:7364: result: no" >&5
+echo "$ac_t""no" 1>&6
+fi
+rm -f conftest.err conftest.$ac_objext conftest.$ac_ext
+
+
+#
+# Check for frexpl, but do more than search for a symbol in standard library
+#
+echo $ac_n "checking for frexpl... $ac_c" 1>&6
+echo "configure:7316: checking for frexpl" >&5
+cat >conftest.$ac_ext <<_ACEOF
+/* confdefs.h.  */
+_ACEOF
+cat confdefs.h >>conftest.$ac_ext
+cat >>conftest.$ac_ext <<_ACEOF
+/* end confdefs.h.  */
+#include <cmath>
+int
+main ()
+{
+frexpl(1.6, 0);
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext
+if { (eval echo "configure:7334: \"$ac_compile\"") >&5
+  (eval $ac_compile) 2>conftest.er1
+  ac_status=$?
+  grep -v '^ *+' conftest.er1 >conftest.err
+  rm -f conftest.er1
+  cat conftest.err >&5
+  echo "configure:7340: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+	 { ac_try='test -z "$ac_cxx_werror_flag"
+			 || test ! -s conftest.err'
+  { (eval echo "configure:7344: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7347: \$? = $ac_status" >&5
+  (exit $ac_status); }; } &&
+	 { ac_try='test -s conftest.$ac_objext'
+  { (eval echo "configure:7350: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7353: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  cat >>confdefs.h <<\_ACEOF
+#define HAVE_FREXPL 1
+_ACEOF
+ echo "configure:7358: result: yes" >&5
+echo "$ac_t""yes" 1>&6
+else
+  echo "configure: failed program was:" >&5
+sed 's/^/| /' conftest.$ac_ext >&5
+
+echo "configure:7364: result: no" >&5
+echo "$ac_t""no" 1>&6
+fi
+rm -f conftest.err conftest.$ac_objext conftest.$ac_ext
+
+
+#
+# Check for floorl, but do more than search for a symbol in standard library
+#
+echo $ac_n "checking for floorl... $ac_c" 1>&6
+echo "configure:7316: checking for floorl" >&5
+cat >conftest.$ac_ext <<_ACEOF
+/* confdefs.h.  */
+_ACEOF
+cat confdefs.h >>conftest.$ac_ext
+cat >>conftest.$ac_ext <<_ACEOF
+/* end confdefs.h.  */
+#include <cmath>
+int
+main ()
+{
+floorl(1.6);
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext
+if { (eval echo "configure:7334: \"$ac_compile\"") >&5
+  (eval $ac_compile) 2>conftest.er1
+  ac_status=$?
+  grep -v '^ *+' conftest.er1 >conftest.err
+  rm -f conftest.er1
+  cat conftest.err >&5
+  echo "configure:7340: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+	 { ac_try='test -z "$ac_cxx_werror_flag"
+			 || test ! -s conftest.err'
+  { (eval echo "configure:7344: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7347: \$? = $ac_status" >&5
+  (exit $ac_status); }; } &&
+	 { ac_try='test -s conftest.$ac_objext'
+  { (eval echo "configure:7350: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7353: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  cat >>confdefs.h <<\_ACEOF
+#define HAVE_FLOORL 1
+_ACEOF
+ echo "configure:7358: result: yes" >&5
+echo "$ac_t""yes" 1>&6
+else
+  echo "configure: failed program was:" >&5
+sed 's/^/| /' conftest.$ac_ext >&5
+
+echo "configure:7364: result: no" >&5
+echo "$ac_t""no" 1>&6
+fi
+rm -f conftest.err conftest.$ac_objext conftest.$ac_ext
+
+
+#
+# Check for ceill, but do more than search for a symbol in standard library
+#
+echo $ac_n "checking for ceill... $ac_c" 1>&6
+echo "configure:7316: checking for ceill" >&5
+cat >conftest.$ac_ext <<_ACEOF
+/* confdefs.h.  */
+_ACEOF
+cat confdefs.h >>conftest.$ac_ext
+cat >>conftest.$ac_ext <<_ACEOF
+/* end confdefs.h.  */
+#include <cmath>
+int
+main ()
+{
+ceill(1.6);
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext
+if { (eval echo "configure:7334: \"$ac_compile\"") >&5
+  (eval $ac_compile) 2>conftest.er1
+  ac_status=$?
+  grep -v '^ *+' conftest.er1 >conftest.err
+  rm -f conftest.er1
+  cat conftest.err >&5
+  echo "configure:7340: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+	 { ac_try='test -z "$ac_cxx_werror_flag"
+			 || test ! -s conftest.err'
+  { (eval echo "configure:7344: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7347: \$? = $ac_status" >&5
+  (exit $ac_status); }; } &&
+	 { ac_try='test -s conftest.$ac_objext'
+  { (eval echo "configure:7350: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7353: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  cat >>confdefs.h <<\_ACEOF
+#define HAVE_CEILL 1
+_ACEOF
+ echo "configure:7358: result: yes" >&5
+echo "$ac_t""yes" 1>&6
+else
+  echo "configure: failed program was:" >&5
+sed 's/^/| /' conftest.$ac_ext >&5
+
+echo "configure:7364: result: no" >&5
+echo "$ac_t""no" 1>&6
+fi
+rm -f conftest.err conftest.$ac_objext conftest.$ac_ext
+
+
+#
+# Check for fmodl, but do more than search for a symbol in standard library
+#
+echo $ac_n "checking for fmodl... $ac_c" 1>&6
+echo "configure:7316: checking for fmodl" >&5
+cat >conftest.$ac_ext <<_ACEOF
+/* confdefs.h.  */
+_ACEOF
+cat confdefs.h >>conftest.$ac_ext
+cat >>conftest.$ac_ext <<_ACEOF
+/* end confdefs.h.  */
+#include <cmath>
+int
+main ()
+{
+fmodl(1.6, 2.2);
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext
+if { (eval echo "configure:7334: \"$ac_compile\"") >&5
+  (eval $ac_compile) 2>conftest.er1
+  ac_status=$?
+  grep -v '^ *+' conftest.er1 >conftest.err
+  rm -f conftest.er1
+  cat conftest.err >&5
+  echo "configure:7340: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+	 { ac_try='test -z "$ac_cxx_werror_flag"
+			 || test ! -s conftest.err'
+  { (eval echo "configure:7344: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7347: \$? = $ac_status" >&5
+  (exit $ac_status); }; } &&
+	 { ac_try='test -s conftest.$ac_objext'
+  { (eval echo "configure:7350: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "configure:7353: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  cat >>confdefs.h <<\_ACEOF
+#define HAVE_FMODL 1
+_ACEOF
+ echo "configure:7358: result: yes" >&5
+echo "$ac_t""yes" 1>&6
+else
+  echo "configure: failed program was:" >&5
+sed 's/^/| /' conftest.$ac_ext >&5
+
+echo "configure:7364: result: no" >&5
+echo "$ac_t""no" 1>&6
+fi
+rm -f conftest.err conftest.$ac_objext conftest.$ac_ext
+ac_ext=cc
+ac_cpp='$CXXCPP $CPPFLAGS'
+ac_compile='$CXX -c $CXXFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CXX -o conftest$ac_exeext $CXXFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
+
+
+#
 # size of datatypes
 #
 
@@ -7672,7 +7672,7 @@
   ac_cv_sizeof_unsigned_char=1
 else
   cat > conftest.$ac_ext <<EOF
-#line 7323 "configure"
+#line 7675 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -7715,7 +7715,7 @@
   ac_cv_sizeof_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 7366 "configure"
+#line 7718 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -7758,7 +7758,7 @@
   ac_cv_sizeof_unsigned_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 7409 "configure"
+#line 7761 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -7801,7 +7801,7 @@
   ac_cv_sizeof_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 7452 "configure"
+#line 7804 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -7844,7 +7844,7 @@
   ac_cv_sizeof_unsigned_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 7495 "configure"
+#line 7847 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -7887,7 +7887,7 @@
   ac_cv_sizeof_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 7538 "configure"
+#line 7890 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -7930,7 +7930,7 @@
   ac_cv_sizeof_unsigned_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 7581 "configure"
+#line 7933 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -7973,7 +7973,7 @@
   ac_cv_sizeof_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 7624 "configure"
+#line 7976 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8016,7 +8016,7 @@
   ac_cv_sizeof_unsigned_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 7667 "configure"
+#line 8019 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8059,7 +8059,7 @@
   ac_cv_sizeof_float=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 7710 "configure"
+#line 8062 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8102,7 +8102,7 @@
   ac_cv_sizeof_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 7753 "configure"
+#line 8105 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8145,7 +8145,7 @@
   ac_cv_sizeof_long_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 7796 "configure"
+#line 8148 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8190,7 +8190,7 @@
   ac_cv_sizeof_unsigned_char=1
 else
   cat > conftest.$ac_ext <<EOF
-#line 7841 "configure"
+#line 8193 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8233,7 +8233,7 @@
   ac_cv_sizeof_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 7884 "configure"
+#line 8236 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8276,7 +8276,7 @@
   ac_cv_sizeof_unsigned_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 7927 "configure"
+#line 8279 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8319,7 +8319,7 @@
   ac_cv_sizeof_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 7970 "configure"
+#line 8322 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8362,7 +8362,7 @@
   ac_cv_sizeof_unsigned_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8013 "configure"
+#line 8365 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8405,7 +8405,7 @@
   ac_cv_sizeof_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 8056 "configure"
+#line 8408 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8448,7 +8448,7 @@
   ac_cv_sizeof_unsigned_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 8099 "configure"
+#line 8451 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8491,7 +8491,7 @@
   ac_cv_sizeof_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 8142 "configure"
+#line 8494 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8534,7 +8534,7 @@
   ac_cv_sizeof_unsigned_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 8185 "configure"
+#line 8537 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8577,7 +8577,7 @@
   ac_cv_sizeof_float=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8228 "configure"
+#line 8580 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8620,7 +8620,7 @@
   ac_cv_sizeof_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 8271 "configure"
+#line 8623 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8663,7 +8663,7 @@
   ac_cv_sizeof_long_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 8314 "configure"
+#line 8666 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8708,7 +8708,7 @@
   ac_cv_sizeof_unsigned_char=1
 else
   cat > conftest.$ac_ext <<EOF
-#line 8359 "configure"
+#line 8711 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8751,7 +8751,7 @@
   ac_cv_sizeof_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8402 "configure"
+#line 8754 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8794,7 +8794,7 @@
   ac_cv_sizeof_unsigned_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8445 "configure"
+#line 8797 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8837,7 +8837,7 @@
   ac_cv_sizeof_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8488 "configure"
+#line 8840 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8880,7 +8880,7 @@
   ac_cv_sizeof_unsigned_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8531 "configure"
+#line 8883 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8923,7 +8923,7 @@
   ac_cv_sizeof_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 8574 "configure"
+#line 8926 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -8966,7 +8966,7 @@
   ac_cv_sizeof_unsigned_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 8617 "configure"
+#line 8969 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9009,7 +9009,7 @@
   ac_cv_sizeof_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 8660 "configure"
+#line 9012 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9052,7 +9052,7 @@
   ac_cv_sizeof_unsigned_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 8703 "configure"
+#line 9055 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9095,7 +9095,7 @@
   ac_cv_sizeof_float=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8746 "configure"
+#line 9098 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9138,7 +9138,7 @@
   ac_cv_sizeof_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 8789 "configure"
+#line 9141 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9181,7 +9181,7 @@
   ac_cv_sizeof_long_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 8832 "configure"
+#line 9184 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9226,7 +9226,7 @@
   ac_cv_sizeof_unsigned_char=1
 else
   cat > conftest.$ac_ext <<EOF
-#line 8877 "configure"
+#line 9229 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9269,7 +9269,7 @@
   ac_cv_sizeof_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8920 "configure"
+#line 9272 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9312,7 +9312,7 @@
   ac_cv_sizeof_unsigned_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 8963 "configure"
+#line 9315 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9355,7 +9355,7 @@
   ac_cv_sizeof_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 9006 "configure"
+#line 9358 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9398,7 +9398,7 @@
   ac_cv_sizeof_unsigned_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 9049 "configure"
+#line 9401 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9441,7 +9441,7 @@
   ac_cv_sizeof_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 9092 "configure"
+#line 9444 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9484,7 +9484,7 @@
   ac_cv_sizeof_unsigned_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 9135 "configure"
+#line 9487 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9527,7 +9527,7 @@
   ac_cv_sizeof_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 9178 "configure"
+#line 9530 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9570,7 +9570,7 @@
   ac_cv_sizeof_unsigned_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 9221 "configure"
+#line 9573 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9613,7 +9613,7 @@
   ac_cv_sizeof_float=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 9264 "configure"
+#line 9616 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9656,7 +9656,7 @@
   ac_cv_sizeof_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 9307 "configure"
+#line 9759 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9699,7 +9699,7 @@
   ac_cv_sizeof_long_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 9350 "configure"
+#line 9702 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9754,7 +9754,7 @@
   ac_cv_sizeof_unsigned_char=1
 else
   cat > conftest.$ac_ext <<EOF
-#line 9405 "configure"
+#line 9757 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9797,7 +9797,7 @@
   ac_cv_sizeof_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 9448 "configure"
+#line 9800 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9840,7 +9840,7 @@
   ac_cv_sizeof_unsigned_int=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 9491 "configure"
+#line 9843 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9883,7 +9883,7 @@
   ac_cv_sizeof_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 9534 "configure"
+#line 9886 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9926,7 +9926,7 @@
   ac_cv_sizeof_unsigned_long=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 9577 "configure"
+#line 9929 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -9969,7 +9969,7 @@
   ac_cv_sizeof_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 9620 "configure"
+#line 9972 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10012,7 +10012,7 @@
   ac_cv_sizeof_unsigned_long_long=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 9663 "configure"
+#line 10015 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10055,7 +10055,7 @@
   ac_cv_sizeof_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 9706 "configure"
+#line 10058 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10098,7 +10098,7 @@
   ac_cv_sizeof_unsigned_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 9749 "configure"
+#line 10101 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10141,7 +10141,7 @@
   ac_cv_sizeof_float=4
 else
   cat > conftest.$ac_ext <<EOF
-#line 9792 "configure"
+#line 10144 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10184,7 +10184,7 @@
   ac_cv_sizeof_double=8
 else
   cat > conftest.$ac_ext <<EOF
-#line 9835 "configure"
+#line 10187 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10227,7 +10227,7 @@
   ac_cv_sizeof_long_double=12
 else
   cat > conftest.$ac_ext <<EOF
-#line 9878 "configure"
+#line 10230 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10275,7 +10275,7 @@
   ac_cv_c_bigendian=unknown
 # See if sys/param.h defines the BYTE_ORDER macro.
 cat > conftest.$ac_ext <<EOF
-#line 9926 "configure"
+#line 10278 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/param.h>
@@ -10290,7 +10290,7 @@
   rm -rf conftest*
   # It does; now see whether it defined to BIG_ENDIAN or not.
 cat > conftest.$ac_ext <<EOF
-#line 9941 "configure"
+#line 10293 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/param.h>
@@ -10321,7 +10321,7 @@
     { echo "configure: error: can not run test program while cross compiling" 1>&2; exit 1; }
 else
   cat > conftest.$ac_ext <<EOF
-#line 9972 "configure"
+#line 10324 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10393,7 +10393,7 @@
   IEEEFP=cross
 else
   cat > conftest.$ac_ext <<EOF
-#line 10044 "configure"
+#line 10396 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -10461,7 +10461,7 @@
 echo "configure:10109: checking for gethostname prototype" >&5
 gethostname_pt=no
 cat > conftest.$ac_ext <<EOF
-#line 10112 "configure"
+#line 10464 "configure"
 #include "confdefs.h"
 #include <unistd.h>
 EOF
@@ -10473,7 +10473,7 @@
 rm -f conftest*
 
 cat > conftest.$ac_ext <<EOF
-#line 10124 "configure"
+#line 10476 "configure"
 #include "confdefs.h"
 #include <sys/socket.h>
 EOF
@@ -10485,7 +10485,7 @@
 rm -f conftest*
 
 cat > conftest.$ac_ext <<EOF
-#line 10136 "configure"
+#line 10488 "configure"
 #include "confdefs.h"
 #include <winsock.h>
 EOF
@@ -10509,7 +10509,7 @@
 echo "configure:10157: checking for finite prototype" >&5
 finite_pt=no
 cat > conftest.$ac_ext <<EOF
-#line 10160 "configure"
+#line 10512 "configure"
 #include "confdefs.h"
 #include <math.h>
 EOF
@@ -10533,7 +10533,7 @@
 echo "configure:10181: checking for strerror prototype" >&5
 strerror_pt=no
 cat > conftest.$ac_ext <<EOF
-#line 10184 "configure"
+#line 10536 "configure"
 #include "confdefs.h"
 #include <string.h>
 EOF
@@ -10558,7 +10558,7 @@
 ftime_pt=no
 # solaris 2.5.1 mentions `ftime' it the header but doesnt have a prototype ...
 cat > conftest.$ac_ext <<EOF
-#line 10209 "configure"
+#line 10561 "configure"
 #include "confdefs.h"
 #include <sys/timeb.h>
 EOF
@@ -10589,7 +10589,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 10240 "configure"
+#line 10592 "configure"
 #include "confdefs.h"
 
 int main() {
@@ -10631,7 +10631,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 10282 "configure"
+#line 10634 "configure"
 #include "confdefs.h"
 
 
@@ -10686,7 +10686,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 10337 "configure"
+#line 10689 "configure"
 #include "confdefs.h"
 
 
@@ -10741,7 +10741,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 10392 "configure"
+#line 10744 "configure"
 #include "confdefs.h"
 
 
@@ -10802,7 +10802,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 10453 "configure"
+#line 10805 "configure"
 #include "confdefs.h"
 
 
@@ -10861,7 +10861,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 10512 "configure"
+#line 10864 "configure"
 #include "confdefs.h"
 
 
@@ -10929,7 +10929,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 10580 "configure"
+#line 10932 "configure"
 #include "confdefs.h"
 
 
@@ -11017,7 +11017,7 @@
   CXXFLAGS="-Werror $CXXFLAGS"
 fi
 cat > conftest.$ac_ext <<EOF
-#line 10668 "configure"
+#line 11020 "configure"
 #include "confdefs.h"
 
 
@@ -11067,7 +11067,7 @@
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 10718 "configure"
+#line 11070 "configure"
 #include "confdefs.h"
 
 int main() {
@@ -11147,7 +11147,7 @@
   EXCEPT=cross
 else
   cat > conftest.$ac_ext <<EOF
-#line 10798 "configure"
+#line 11150 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -11229,7 +11229,7 @@
   STDEH=cross
 else
   cat > conftest.$ac_ext <<EOF
-#line 10880 "configure"
+#line 11232 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -11419,7 +11419,7 @@
   SHRUN=cross-compiling
 else
   cat > conftest.$ac_ext <<EOF
-#line 11070 "configure"
+#line 11422 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -11489,7 +11489,7 @@
   SHEXRUN=cross-compiling
 else
   cat > conftest.$ac_ext <<EOF
-#line 11140 "configure"
+#line 11492 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -11576,7 +11576,7 @@
   DLRUN=cross-compiling
 else
   cat > conftest.$ac_ext <<EOF
-#line 11227 "configure"
+#line 11579 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
@@ -11638,7 +11638,7 @@
   DLRUN=cross-compiling
 else
   cat > conftest.$ac_ext <<EOF
-#line 11289 "configure"
+#line 11641 "configure"
 #include "confdefs.h"
 #ifdef __cplusplus
 #include <stdlib.h>
